@@ -68,18 +68,13 @@ typedef enum
 
 typedef enum
 {
-  GTK_CMCTREE_LINES_NONE,
-  GTK_CMCTREE_LINES_SOLID,
-  GTK_CMCTREE_LINES_DOTTED,
-  GTK_CMCTREE_LINES_TABBED
+  GTK_CMCTREE_LINES_NONE
 } GtkCMCTreeLineStyle;
 
 typedef enum
 {
   GTK_CMCTREE_EXPANDER_NONE,
-  GTK_CMCTREE_EXPANDER_SQUARE,
-  GTK_CMCTREE_EXPANDER_TRIANGLE,
-  GTK_CMCTREE_EXPANDER_CIRCULAR
+  GTK_CMCTREE_EXPANDER_TRIANGLE
 } GtkCMCTreeExpanderStyle;
 
 typedef enum
@@ -116,8 +111,6 @@ struct _GtkCMCTree
 {
   GtkCMCList clist;
   
-  GdkGC *lines_gc;
-  
   gint tree_indent;
   gint tree_spacing;
   gint tree_column;
@@ -159,10 +152,8 @@ struct _GtkCMCTreeRow
   GtkCMCTreeNode *sibling;
   GtkCMCTreeNode *children;
   
-  GdkPixmap *pixmap_closed;
-  GdkBitmap *mask_closed;
-  GdkPixmap *pixmap_opened;
-  GdkBitmap *mask_opened;
+  GdkPixbuf *pixbuf_closed;
+  GdkPixbuf *pixbuf_opened;
   
   guint16 level;
   
@@ -190,10 +181,8 @@ GtkCMCTreeNode * gtk_cmctree_insert_node             (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *sibling,
 						  gchar        *text[],
 						  guint8        spacing,
-						  GdkPixmap    *pixmap_closed,
-						  GdkBitmap    *mask_closed,
-						  GdkPixmap    *pixmap_opened,
-						  GdkBitmap    *mask_opened,
+						  GdkPixbuf    *pixbuf_closed,
+						  GdkPixbuf    *pixbuf_opened,
 						  gboolean      is_leaf,
 						  gboolean      expanded);
 void gtk_cmctree_remove_node                       (GtkCMCTree     *ctree, 
@@ -264,6 +253,10 @@ GList * gtk_cmctree_find_all_by_row_data_custom    (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gpointer      data,
 						  GCompareFunc  func);
+
+/* This assumes that x and y coordinates are inside the clist_window.
+ * Returns true if the coordinates are inside a tree expander on
+ * one of the rows. */
 gboolean gtk_cmctree_is_hot_spot                   (GtkCMCTree     *ctree,
 					          gint          x,
 					          gint          y);
@@ -314,26 +307,22 @@ void gtk_cmctree_node_set_text                     (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gint          column,
 						  const gchar  *text);
-void gtk_cmctree_node_set_pixmap                   (GtkCMCTree     *ctree,
+void gtk_cmctree_node_set_pixbuf                   (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gint          column,
-						  GdkPixmap    *pixmap,
-						  GdkBitmap    *mask);
+						  GdkPixbuf    *pixbuf);
 void gtk_cmctree_node_set_pixtext                  (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gint          column,
 						  const gchar  *text,
 						  guint8        spacing,
-						  GdkPixmap    *pixmap,
-						  GdkBitmap    *mask);
+						  GdkPixbuf    *pixbuf);
 void gtk_cmctree_set_node_info                     (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  const gchar  *text,
 						  guint8        spacing,
-						  GdkPixmap    *pixmap_closed,
-						  GdkBitmap    *mask_closed,
-						  GdkPixmap    *pixmap_opened,
-						  GdkBitmap    *mask_opened,
+						  GdkPixbuf    *pixbuf_closed,
+						  GdkPixbuf    *pixbuf_opened,
 						  gboolean      is_leaf,
 						  gboolean      expanded);
 void gtk_cmctree_node_set_shift                    (GtkCMCTree     *ctree,
@@ -353,26 +342,22 @@ gboolean gtk_cmctree_node_get_text                 (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gint          column,
 						  gchar       **text);
-gboolean gtk_cmctree_node_get_pixmap               (GtkCMCTree     *ctree,
+gboolean gtk_cmctree_node_get_pixbuf               (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gint          column,
-						  GdkPixmap   **pixmap,
-						  GdkBitmap   **mask);
+						  GdkPixbuf   **pixbuf);
 gboolean gtk_cmctree_node_get_pixtext              (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gint          column,
 						  gchar       **text,
 						  guint8       *spacing,
-						  GdkPixmap   **pixmap,
-						  GdkBitmap   **mask);
+						  GdkPixbuf   **pixbuf);
 gboolean gtk_cmctree_get_node_info                 (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gchar       **text,
 						  guint8       *spacing,
-						  GdkPixmap   **pixmap_closed,
-						  GdkBitmap   **mask_closed,
-						  GdkPixmap   **pixmap_opened,
-						  GdkBitmap   **mask_opened,
+						  GdkPixbuf   **pixbuf_closed,
+						  GdkPixbuf   **pixbuf_opened,
 						  gboolean     *is_leaf,
 						  gboolean     *expanded);
 void gtk_cmctree_node_set_row_style                (GtkCMCTree     *ctree,
@@ -389,10 +374,10 @@ GtkStyle * gtk_cmctree_node_get_cell_style         (GtkCMCTree     *ctree,
 						  gint          column);
 void gtk_cmctree_node_set_foreground               (GtkCMCTree       *ctree,
 						  GtkCMCTreeNode   *node,
-						  const GdkColor *color);
+						  const GdkRGBA *color);
 void gtk_cmctree_node_set_background               (GtkCMCTree       *ctree,
 						  GtkCMCTreeNode   *node,
-						  const GdkColor *color);
+						  const GdkRGBA *color);
 void gtk_cmctree_node_set_row_data                 (GtkCMCTree     *ctree,
 						  GtkCMCTreeNode *node,
 						  gpointer      data);
